# Managing Surveys and Viewing Results
### On this page
  * [Filter, Sort, and Search Surveys](https://help.sap.com/docs/leanix/ea/managing-surveys-and-viewing-results#filter,-sort,-and-search-surveys)
  * [Viewing Survey Results](https://help.sap.com/docs/leanix/ea/managing-surveys-and-viewing-results#viewing-survey-results)
  * [Finishing a Survey](https://help.sap.com/docs/leanix/ea/managing-surveys-and-viewing-results#finishing-a-survey)
  * [Survey History](https://help.sap.com/docs/leanix/ea/managing-surveys-and-viewing-results#survey-history)
  * [Restarting a Survey](https://help.sap.com/docs/leanix/ea/managing-surveys-and-viewing-results#restarting-a-survey)
  * [Deleting a Survey](https://help.sap.com/docs/leanix/ea/managing-surveys-and-viewing-results#deleting-a-survey)
  * [Deleting a Survey Run](https://help.sap.com/docs/leanix/ea/managing-surveys-and-viewing-results#deleting-a-survey-run)


Manage all your surveys centrally in the Collaboration tab of your workspace. Easily filter, sort, and search surveys, view results, finish, rerun, restart, or delete survey runs.
You can find a comprehensive overview of all your surveys in the Collaboration tab, making it easy to access and manage them centrally. Select the Manage Surveys section on the left side pane of the collaboration tab to view all existing surveys. This section, by default, is accessible only to admins. However, admins can configure permissions to allow non-admins to create surveys, collect responses, and access survey results. To learn how to configure survey permissions, see [Configuring Survey Permissions for Non-Admin Roles](https://help.sap.com/docs/leanix/ea/extended-guide-on-survey-features?locale=en-US&state=PRODUCTION&version=CLOUD#loio2759f4557a4410148566fbe869571509__section_lqh_4b4_sfc).
